/*
 *  anthyimportwordpane.h
 *  Copyright(C) 2003- Masahito Omote <omote@utyuuzin.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __ANTHY_IMPORTWORDPANE_H__
#define __ANTHY_IMPORTWORDPANE_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

typedef struct _anthy_imortwordpane {
	GtkWidget *pane;

	/* Import */
	GtkWidget *importfilename;
	GtkWidget *button_import_getfilename;
	GtkWidget *button_doimport;
	GtkWidget *opt_dic_import_type;

	/* Export */
	GtkWidget *exportfilename;
	GtkWidget *button_export_getfilename;
	GtkWidget *button_doexport;
	GtkWidget *opt_dic_export_type;
} AnthyImportWordPane;

int create_anthy_importwordpane(AnthyImportWordPane *pane);
int show_anthy_importwordpane(AnthyImportWordPane *pane);

#endif /* __ANTHY_IMPORTWORDPANE_H__ */
